@@ -20,7 +20,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "1.1.8"
+__version__ = "2.0.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Pixelbuf.git"
 
 DOTSTAR_LED_START_FULL_BRIGHT = 0xFF
@@ -44,7 +44,8 @@ class PixelBuf:  # pylint: disable=too-many-instance-attributes
 
     def __init__(  # pylint: disable=too-many-locals,too-many-arguments
         self,
-        n: int,
+        size: int,
+        *,
         byteorder: str = "BGR",
         brightness: float = 1.0,
         auto_write: bool = False,
@@ -57,7 +58,7 @@ class PixelBuf:  # pylint: disable=too-many-instance-attributes
         self.auto_write = False
 
         effective_bpp = 4 if dotstar_mode else bpp
-        _bytes = effective_bpp * n
+        _bytes = effective_bpp * size
         buf = bytearray(_bytes)
         offset = 0
 
@@ -72,7 +73,7 @@ class PixelBuf:  # pylint: disable=too-many-instance-attributes
                 raise TypeError("trailer must be a bytearray")
             buf += trailer
 
-        self._pixels = n
+        self._pixels = size
         self._bytes = _bytes
         self._byteorder = byteorder_tuple
         self._byteorder_string = byteorder
